"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const formatDuration_1 = require("./formatDuration");
class JsonReporter {
    constructor(options) {
        this.options = options;
    }
    log(entry) {
        if (this.options.logLevel >= entry.level) {
            console.log(JSON.stringify(entry));
        }
    }
    summarize(context) {
        const { measures, tasks } = context;
        const summary = {};
        const taskStats = [];
        for (const task of tasks.values()) {
            taskStats.push({
                package: task.info.name,
                task: task.task,
                duration: formatDuration_1.hrToSeconds(task.duration),
                status: task.status,
                npmArgs: task.npmArgs,
            });
        }
        if (measures.failedTasks && measures.failedTasks.length > 0) {
            summary.failedTasks = measures.failedTasks;
        }
        summary.duration = formatDuration_1.hrToSeconds(measures.duration);
        summary.taskStats = taskStats;
        console.log(JSON.stringify({ summary }));
    }
}
exports.JsonReporter = JsonReporter;
